pub struct Bls12_381;Trait Implementations
Sourceimpl Pairing for Bls12_381
impl Pairing for Bls12_381
Sourcetype BaseField = Fp<MontBackend<FqConfig, 6>, 6>
type BaseField = Fp<MontBackend<FqConfig, 6>, 6>
This is the base field of the G1 group and base prime field of G2.
Sourcetype ScalarField = Fp<MontBackend<FrConfig, 4>, 4>
type ScalarField = Fp<MontBackend<FrConfig, 4>, 4>
This is the scalar field of the G1/G2 groups.
type G1Affine = Affine<<Config as Bls12Config>::G1Config>
Sourcetype G1Prepared = G1Prepared<Config>
type G1Prepared = G1Prepared<Config>
A G1 element that has been preprocessed for use in a pairing.
Sourcetype G2Affine = Affine<<Config as Bls12Config>::G2Config>
type G2Affine = Affine<<Config as Bls12Config>::G2Config>
The affine representation of an element in G2.
Sourcetype G2Prepared = G2PreparedNoAlloc
type G2Prepared = G2PreparedNoAlloc
A G2 element that has been preprocessed for use in a pairing.
Sourcetype TargetField = QuadExtField<Fp12ConfigWrapper<Fq12Config>>
type TargetField = QuadExtField<Fp12ConfigWrapper<Fq12Config>>
The extension field that hosts the target group of the pairing.
Sourcefn multi_miller_loop(
a: impl IntoIterator<Item = impl Into<Self::G1Prepared>>,
b: impl IntoIterator<Item = impl Into<Self::G2Prepared>>,
) -> MillerLoopOutput<Self>
fn multi_miller_loop( a: impl IntoIterator<Item = impl Into<Self::G1Prepared>>, b: impl IntoIterator<Item = impl Into<Self::G2Prepared>>, ) -> MillerLoopOutput<Self>
Computes the product of Miller loops for some number of (G1, G2) pairs.
Sourcefn final_exponentiation(
f: MillerLoopOutput<Self>,
) -> Option<PairingOutput<Self>>
fn final_exponentiation( f: MillerLoopOutput<Self>, ) -> Option<PairingOutput<Self>>
Performs final exponentiation of the result of a
Self::multi_miller_loop.fn miller_loop(
a: impl Into<Self::G1Prepared>,
b: impl Into<Self::G2Prepared>,
) -> MillerLoopOutput<Self>
fn miller_loop( a: impl Into<Self::G1Prepared>, b: impl Into<Self::G2Prepared>, ) -> MillerLoopOutput<Self>
Computes the Miller loop over
a and b.fn multi_pairing(
a: impl IntoIterator<Item = impl Into<Self::G1Prepared>>,
b: impl IntoIterator<Item = impl Into<Self::G2Prepared>>,
) -> PairingOutput<Self>
fn multi_pairing( a: impl IntoIterator<Item = impl Into<Self::G1Prepared>>, b: impl IntoIterator<Item = impl Into<Self::G2Prepared>>, ) -> PairingOutput<Self>
Computes a “product” of pairings.
impl Copy for Bls12_381
impl Eq for Bls12_381
impl StructuralPartialEq for Bls12_381