Error

Struct Error 

#[non_exhaustive]
pub struct Error {}
Signature errors.

This type is deliberately opaque as to avoid sidechannel leakage which could potentially be used recover signing private keys or forge signatures (e.g. BB’06).

When the std feature is enabled, it impls [std::error::Error] and supports an optional [std::error::Error::source], which can be used by things like remote signers (e.g. HSM, KMS) to report I/O or auth errors.

Implementations



impl Error

pub fn new() -> Error

Create a new error with no associated source