PrehashSignature

Trait PrehashSignature 

pub trait PrehashSignature {
    type Digest: Digest;
}
Marker trait for Signature types computable as ๐’(๐‡(๐’Ž)) i.e. ones which prehash a message to be signed as ๐‡(๐’Ž)

Where:

  • ๐’: signature algorithm
  • ๐‡: hash (a.k.a. digest) function
  • ๐’Ž: message

This approach is relatively common in signature schemes based on the Fiat-Shamir heuristic.

For signature types that implement this trait, when the derive crate feature is enabled a custom derive for Signer is available for any types that impl DigestSigner, and likewise for deriving Verifier for types which impl DigestVerifier.

Required Associated Types

type Digest: Digest

Preferred Digest algorithm to use when computing this signature type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl<C> PrehashSignature for Signature<C>

Available on crate feature digest only.


impl<C> PrehashSignature for Signature<C>

Available on crate features digest and hazmat only.

Implementors