RandomizedDigestSigner

Trait RandomizedDigestSigner 

pub trait RandomizedDigestSigner<D, S>
where D: Digest,
{ // Required method fn try_sign_digest_with_rng( &self, rng: &mut impl CryptoRngCore, digest: D, ) -> Result<S, Error>; // Provided method fn sign_digest_with_rng(&self, rng: &mut impl CryptoRngCore, digest: D) -> S { ... } }
Combination of DigestSigner and RandomizedSigner with support for computing a signature over a digest which requires entropy from an RNG.

Required Methods

fn try_sign_digest_with_rng( &self, rng: &mut impl CryptoRngCore, digest: D, ) -> Result<S, Error>

Attempt to sign the given prehashed message Digest, returning a digital signature on success, or an error if something went wrong.

Provided Methods

fn sign_digest_with_rng(&self, rng: &mut impl CryptoRngCore, digest: D) -> S

Sign the given prehashed message Digest, returning a signature.

Panics in the event of a signing error.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl<C, D> RandomizedDigestSigner<D, Signature<C>> for SigningKey<C>

Available on crate feature der only.


fn try_sign_digest_with_rng( &self, rng: &mut impl CryptoRngCore, msg_digest: D, ) -> Result<Signature<C>, Error>



impl<C, D> RandomizedDigestSigner<D, Signature<C>> for SigningKey<C>



fn try_sign_digest_with_rng( &self, rng: &mut impl CryptoRngCore, msg_digest: D, ) -> Result<Signature<C>, Error>

Implementors