Trait Retrieve
pub trait Retrieve {
type Output;
// Required method
fn retrieve(&self) -> Self::Output;
}Expand description
A generalization for numbers kept in optimized representations (e.g. Montgomery) that can be converted back to the original form.
Required Associated Types
type Output
type Output
The original type.