Struct Reciprocal
pub struct Reciprocal { /* private fields */ }Expand description
A pre-calculated reciprocal for division by a single limb.
Implementations
impl Reciprocal
impl Reciprocal
pub const fn ct_new(divisor: Limb) -> (Reciprocal, CtChoice)
pub const fn ct_new(divisor: Limb) -> (Reciprocal, CtChoice)
Pre-calculates a reciprocal for a known divisor,
to be used in the single-limb division later.
Returns the reciprocal, and the truthy value if divisor != 0
and the falsy value otherwise.
Note: if the returned flag is falsy, the returned reciprocal object is still self-consistent and can be passed to functions here without causing them to panic, but the results are naturally not to be used.
pub const fn default() -> Reciprocal
pub const fn default() -> Reciprocal
Returns a default instance of this object.
It is a self-consistent Reciprocal that will not cause panics in functions that take it.
NOTE: intended for using it as a placeholder during compile-time array generation, don’t rely on the contents.
pub fn new(divisor: Limb) -> CtOption<Reciprocal>
pub fn new(divisor: Limb) -> CtOption<Reciprocal>
A non-const-fn version of new_const(), wrapping the result in a CtOption.