Uint

Struct Uint 

pub struct Uint<const LIMBS: usize> { /* private fields */ }
Stack-allocated big unsigned integer.

Generic over the given number of LIMBS

Encoding support

This type supports many different types of encodings, either via the Encoding trait or various const fn decoding and encoding functions that can be used with Uint constants.

Optional crate features for encoding (off-by-default):

Implementations



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn adc(&self, rhs: &Uint<LIMBS>, carry: Limb) -> (Uint<LIMBS>, Limb)

Computes a + b + carry, returning the result along with the new carry.

pub const fn saturating_add(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Perform saturating addition, returning MAX on overflow.

pub const fn wrapping_add(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Perform wrapping addition, discarding overflow.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn add_mod(&self, rhs: &Uint<LIMBS>, p: &Uint<LIMBS>) -> Uint<LIMBS>

Computes self + rhs mod p.

Assumes self + rhs as unbounded integer is < 2p.

pub const fn add_mod_special(&self, rhs: &Uint<LIMBS>, c: Limb) -> Uint<LIMBS>

Computes self + rhs mod p for the special modulus p = MAX+1-c where c is small enough to fit in a single Limb.

Assumes self + rhs as unbounded integer is < 2p.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn bitand(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Computes bitwise a & b.

pub const fn wrapping_and(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Perform wrapping bitwise AND.

There’s no way wrapping could ever happen. This function exists so that all operations are accounted for in the wrapping operations

pub fn checked_and(&self, rhs: &Uint<LIMBS>) -> CtOption<Uint<LIMBS>>

Perform checked bitwise AND, returning a CtOption which is_some always



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn not(&self) -> Uint<LIMBS>

Computes bitwise !a.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn bitor(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Computes bitwise a & b.

pub const fn wrapping_or(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Perform wrapping bitwise OR.

There’s no way wrapping could ever happen. This function exists so that all operations are accounted for in the wrapping operations

pub fn checked_or(&self, rhs: &Uint<LIMBS>) -> CtOption<Uint<LIMBS>>

Perform checked bitwise OR, returning a CtOption which is_some always



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn bitxor(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Computes bitwise a ^ b.

pub const fn wrapping_xor(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Perform wrapping bitwise `XOR``.

There’s no way wrapping could ever happen. This function exists so that all operations are accounted for in the wrapping operations

pub fn checked_xor(&self, rhs: &Uint<LIMBS>) -> CtOption<Uint<LIMBS>>

Perform checked bitwise XOR, returning a CtOption which is_some always



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn bit_vartime(&self, index: usize) -> bool

Returns true if the bit at position index is set, false otherwise.

Remarks

This operation is variable time with respect to index only.

pub const fn bits_vartime(&self) -> usize

Calculate the number of bits needed to represent this number.

pub const fn leading_zeros(&self) -> usize

Calculate the number of leading zeros in the binary representation of this number.

pub const fn leading_zeros_vartime(&self) -> usize

Calculate the number of leading zeros in the binary representation of this number, variable time in self.

pub const fn trailing_zeros(&self) -> usize

Calculate the number of trailing zeros in the binary representation of this number.

pub const fn trailing_zeros_vartime(&self) -> usize

Calculate the number of trailing zeros in the binary representation of this number, variable time in self.

pub const fn trailing_ones(&self) -> usize

Calculate the number of trailing ones in the binary representation of this number.

pub const fn trailing_ones_vartime(&self) -> usize

Calculate the number of trailing ones in the binary representation of this number, variable time in self.

pub const fn bits(&self) -> usize

Calculate the number of bits needed to represent this number.

pub const fn bit(&self, index: usize) -> CtChoice

Get the value of the bit at position index, as a truthy or falsy CtChoice. Returns the falsy value for indices out of range.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn cmp_vartime(&self, rhs: &Uint<LIMBS>) -> Ordering

Returns the Ordering between self and rhs in variable time.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn ct_div_rem_limb_with_reciprocal( &self, reciprocal: &Reciprocal, ) -> (Uint<LIMBS>, Limb)

Computes self / rhs using a pre-made reciprocal, returns the quotient (q) and remainder (r).

pub fn div_rem_limb_with_reciprocal( &self, reciprocal: &CtOption<Reciprocal>, ) -> CtOption<(Uint<LIMBS>, Limb)>

Computes self / rhs using a pre-made reciprocal, returns the quotient (q) and remainder (r).

pub fn div_rem_limb(&self, rhs: NonZero<Limb>) -> (Uint<LIMBS>, Limb)

Computes self / rhs, returns the quotient (q) and remainder (r).

pub const fn const_rem(&self, rhs: &Uint<LIMBS>) -> (Uint<LIMBS>, CtChoice)

Computes self % rhs, returns the remainder and and the truthy value for is_some or the falsy value for is_none.

NOTE: Use only if you need to access const fn. Otherwise use Self::rem. This is variable only with respect to rhs.

When used with a fixed rhs, this function is constant-time with respect to self.

pub const fn const_rem_wide( lower_upper: (Uint<LIMBS>, Uint<LIMBS>), rhs: &Uint<LIMBS>, ) -> (Uint<LIMBS>, CtChoice)

Computes self % rhs, returns the remainder and and the truthy value for is_some or the falsy value for is_none.

This is variable only with respect to rhs.

When used with a fixed rhs, this function is constant-time with respect to self.

pub const fn rem2k(&self, k: usize) -> Uint<LIMBS>

Computes self % 2^k. Faster than reduce since its a power of 2. Limited to 2^16-1 since Uint doesn’t support higher.

pub fn div_rem(&self, rhs: &NonZero<Uint<LIMBS>>) -> (Uint<LIMBS>, Uint<LIMBS>)

Computes self / rhs, returns the quotient, remainder.

pub fn rem(&self, rhs: &NonZero<Uint<LIMBS>>) -> Uint<LIMBS>

Computes self % rhs, returns the remainder.

pub const fn wrapping_div(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Wrapped division is just normal division i.e. self / rhs There’s no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.

Panics if rhs == 0.

pub fn checked_div(&self, rhs: &Uint<LIMBS>) -> CtOption<Uint<LIMBS>>

Perform checked division, returning a CtOption which is_some only if the rhs != 0

pub const fn wrapping_rem(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Wrapped (modular) remainder calculation is just self % rhs. There’s no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.

Panics if rhs == 0.

pub fn checked_rem(&self, rhs: &Uint<LIMBS>) -> CtOption<Uint<LIMBS>>

Perform checked reduction, returning a CtOption which is_some only if the rhs != 0



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn from_be_slice(bytes: &[u8]) -> Uint<LIMBS>

Create a new Uint from the provided big endian bytes.

pub const fn from_be_hex(hex: &str) -> Uint<LIMBS>

Create a new Uint from the provided big endian hex string.

pub const fn from_le_slice(bytes: &[u8]) -> Uint<LIMBS>

Create a new Uint from the provided little endian bytes.

pub const fn from_le_hex(hex: &str) -> Uint<LIMBS>

Create a new Uint from the provided little endian hex string.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn from_u8(n: u8) -> Uint<LIMBS>

Create a Uint from a u8 (const-friendly)

pub const fn from_u16(n: u16) -> Uint<LIMBS>

Create a Uint from a u16 (const-friendly)

pub const fn from_u32(n: u32) -> Uint<LIMBS>

Create a Uint from a u32 (const-friendly)

pub const fn from_u64(n: u64) -> Uint<LIMBS>

Create a Uint from a u64 (const-friendly)

pub const fn from_u128(n: u128) -> Uint<LIMBS>

Create a Uint from a u128 (const-friendly)

pub const fn from_word(n: u64) -> Uint<LIMBS>

Create a Uint from a Word (const-friendly)

pub const fn from_wide_word(n: u128) -> Uint<LIMBS>

Create a Uint from a WideWord (const-friendly)



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn inv_mod2k_vartime(&self, k: usize) -> Uint<LIMBS>

Computes 1/self mod 2^k. This method is constant-time w.r.t. self but not k.

Conditions: self < 2^k and self must be odd

pub const fn inv_mod2k(&self, k: usize) -> Uint<LIMBS>

Computes 1/self mod 2^k.

Conditions: self < 2^k and self must be odd

pub const fn inv_odd_mod_bounded( &self, modulus: &Uint<LIMBS>, bits: usize, modulus_bits: usize, ) -> (Uint<LIMBS>, CtChoice)

Computes the multiplicative inverse of self mod modulus, where modulus is odd. In other words self^-1 mod modulus. bits and modulus_bits are the bounds on the bit size of self and modulus, respectively (the inversion speed will be proportional to bits + modulus_bits). The second element of the tuple is the truthy value if an inverse exists, otherwise it is a falsy value.

Note: variable time in bits and modulus_bits.

The algorithm is the same as in GMP 6.2.1’s mpn_sec_invert.

pub const fn inv_odd_mod( &self, modulus: &Uint<LIMBS>, ) -> (Uint<LIMBS>, CtChoice)

Computes the multiplicative inverse of self mod modulus, where modulus is odd. Returns (inverse, CtChoice::TRUE) if an inverse exists, otherwise (undefined, CtChoice::FALSE).

pub const fn inv_mod(&self, modulus: &Uint<LIMBS>) -> (Uint<LIMBS>, CtChoice)

Computes the multiplicative inverse of self mod modulus. Returns (inverse, CtChoice::TRUE) if an inverse exists, otherwise (undefined, CtChoice::FALSE).



impl<const LIMBS: usize> Uint<LIMBS>

pub fn mul<const HLIMBS: usize>( &self, rhs: &Uint<HLIMBS>, ) -> <Uint<HLIMBS> as ConcatMixed<Uint<LIMBS>>>::MixedOutput
where Uint<HLIMBS>: ConcatMixed<Uint<LIMBS>>,

Multiply self by rhs, returning a concatenated “wide” result.

pub const fn mul_wide<const HLIMBS: usize>( &self, rhs: &Uint<HLIMBS>, ) -> (Uint<LIMBS>, Uint<HLIMBS>)

Compute “wide” multiplication, with a product twice the size of the input.

Returns a tuple containing the (lo, hi) components of the product.

Ordering note

Releases of crypto-bigint prior to v0.3 used (hi, lo) ordering instead. This has been changed for better consistency with the rest of the APIs in this crate.

For more info see: https://github.com/RustCrypto/crypto-bigint/issues/4

pub const fn saturating_mul<const HLIMBS: usize>( &self, rhs: &Uint<HLIMBS>, ) -> Uint<LIMBS>

Perform saturating multiplication, returning MAX on overflow.

pub const fn wrapping_mul<const H: usize>(&self, rhs: &Uint<H>) -> Uint<LIMBS>

Perform wrapping multiplication, discarding overflow.

pub fn square(&self) -> <Uint<LIMBS> as Concat>::Output
where Uint<LIMBS>: Concat,

Square self, returning a concatenated “wide” result.

pub const fn square_wide(&self) -> (Uint<LIMBS>, Uint<LIMBS>)

Square self, returning a “wide” result in two parts as (lo, hi).



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn mul_mod_special(&self, rhs: &Uint<LIMBS>, c: Limb) -> Uint<LIMBS>

Computes self * rhs mod p for the special modulus p = MAX+1-c where c is small enough to fit in a single Limb. For the modulus reduction, this function implements Algorithm 14.47 from the “Handbook of Applied Cryptography”, by A. Menezes, P. van Oorschot, and S. Vanstone, CRC Press, 1996.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn wrapping_neg(&self) -> Uint<LIMBS>

Perform wrapping negation.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn neg_mod(&self, p: &Uint<LIMBS>) -> Uint<LIMBS>

Computes -a mod p. Assumes self is in [0, p).

pub const fn neg_mod_special(&self, c: Limb) -> Uint<LIMBS>

Computes -a mod p for the special modulus p = MAX+1-c where c is small enough to fit in a single Limb.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn resize<const T: usize>(&self) -> Uint<T>

Construct a Uint<T> from the unsigned integer value, truncating the upper bits if the value is too large to be represented.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn shl_vartime(&self, n: usize) -> Uint<LIMBS>

Computes self << shift.

NOTE: this operation is variable time with respect to n ONLY.

When used with a fixed n, this function is constant-time with respect to self.

pub const fn shl_vartime_wide( lower_upper: (Uint<LIMBS>, Uint<LIMBS>), n: usize, ) -> (Uint<LIMBS>, Uint<LIMBS>)

Computes a left shift on a wide input as (lo, hi).

NOTE: this operation is variable time with respect to n ONLY.

When used with a fixed n, this function is constant-time with respect to self.

pub const fn shl(&self, shift: usize) -> Uint<LIMBS>

Computes self << n. Returns zero if n >= Self::BITS.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn shr_vartime(&self, shift: usize) -> Uint<LIMBS>

Computes self >> n.

NOTE: this operation is variable time with respect to n ONLY.

When used with a fixed n, this function is constant-time with respect to self.

pub const fn shr_vartime_wide( lower_upper: (Uint<LIMBS>, Uint<LIMBS>), n: usize, ) -> (Uint<LIMBS>, Uint<LIMBS>)

Computes a right shift on a wide input as (lo, hi).

NOTE: this operation is variable time with respect to n ONLY.

When used with a fixed n, this function is constant-time with respect to self.

pub const fn shr(&self, shift: usize) -> Uint<LIMBS>

Computes self << n. Returns zero if n >= Self::BITS.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn sqrt(&self) -> Uint<LIMBS>

👎Deprecated since 0.5.3: This functionality will be moved to sqrt_vartime in a future release.

pub const fn sqrt_vartime(&self) -> Uint<LIMBS>

Computes √(self) Uses Brent & Zimmermann, Modern Computer Arithmetic, v0.5.9, Algorithm 1.13

Callers can check if self is a square by squaring the result

pub const fn wrapping_sqrt(&self) -> Uint<LIMBS>

👎Deprecated since 0.5.3: This functionality will be moved to wrapping_sqrt_vartime in a future release.

pub const fn wrapping_sqrt_vartime(&self) -> Uint<LIMBS>

Wrapped sqrt is just normal √(self) There’s no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.

pub fn checked_sqrt(&self) -> CtOption<Uint<LIMBS>>

👎Deprecated since 0.5.3: This functionality will be moved to checked_sqrt_vartime in a future release.

pub fn checked_sqrt_vartime(&self) -> CtOption<Uint<LIMBS>>

Perform checked sqrt, returning a CtOption which is_some only if the √(self)² == self



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn sbb(&self, rhs: &Uint<LIMBS>, borrow: Limb) -> (Uint<LIMBS>, Limb)

Computes a - (b + borrow), returning the result along with the new borrow.

pub const fn saturating_sub(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Perform saturating subtraction, returning ZERO on underflow.

pub const fn wrapping_sub(&self, rhs: &Uint<LIMBS>) -> Uint<LIMBS>

Perform wrapping subtraction, discarding underflow and wrapping around the boundary of the type.



impl<const LIMBS: usize> Uint<LIMBS>

pub const fn sub_mod(&self, rhs: &Uint<LIMBS>, p: &Uint<LIMBS>) -> Uint<LIMBS>

Computes self - rhs mod p.

Assumes self - rhs as unbounded signed integer is in [-p, p).

pub const fn sub_mod_special(&self, rhs: &Uint<LIMBS>, c: Limb) -> Uint<LIMBS>

Computes self - rhs mod p for the special modulus p = MAX+1-c where c is small enough to fit in a single Limb.

Assumes self - rhs as unbounded signed integer is in [-p, p).



impl<const LIMBS: usize> Uint<LIMBS>

pub const ZERO: Uint<LIMBS>

The value 0.

pub const ONE: Uint<LIMBS>

The value 1.

pub const MAX: Uint<LIMBS>

Maximum value this Uint can express.

pub const BITS: usize

Total size of the represented integer in bits.

pub const BYTES: usize

Total size of the represented integer in bytes.

pub const LIMBS: usize = LIMBS

The number of limbs used on this platform.

pub const fn new(limbs: [Limb; LIMBS]) -> Uint<LIMBS>

Const-friendly Uint constructor.

pub const fn from_words(arr: [u64; LIMBS]) -> Uint<LIMBS>

Create a Uint from an array of Words (i.e. word-sized unsigned integers).

pub const fn to_words(self) -> [u64; LIMBS]

Create an array of Words (i.e. word-sized unsigned integers) from a Uint.

pub const fn as_words(&self) -> &[u64; LIMBS]

Borrow the inner limbs as an array of Words.

pub fn as_words_mut(&mut self) -> &mut [u64; LIMBS]

Borrow the inner limbs as a mutable array of Words.

pub const fn as_limbs(&self) -> &[Limb; LIMBS]

Borrow the limbs of this Uint.

pub fn as_limbs_mut(&mut self) -> &mut [Limb; LIMBS]

Borrow the limbs of this Uint mutably.

pub const fn to_limbs(self) -> [Limb; LIMBS]

Convert this Uint into its inner limbs.



impl Uint<crypto_bigint::::uint::{impl#49}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#49}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U128::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U128::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#52}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#52}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#54}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#54}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U256::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U256::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#57}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#57}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#59}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#59}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U384::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U384::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#62}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#62}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#64}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#64}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U512::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U512::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#67}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#67}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#69}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#69}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U640::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U640::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#72}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#72}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#74}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#74}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U768::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U768::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#77}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#77}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#79}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#79}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U896::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U896::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#82}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#82}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#84}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#84}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U1024::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U1024::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#87}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#87}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#89}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#89}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U1280::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U1280::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#92}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#92}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#94}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#94}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U1536::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U1536::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#97}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#97}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#99}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#99}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U1792::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U1792::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#102}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#102}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#104}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#104}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U2048::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U2048::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#107}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#107}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#109}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#109}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U3072::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U3072::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#112}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#112}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#114}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#114}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U3584::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U3584::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#117}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#117}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#119}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#119}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U4096::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U4096::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#122}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#122}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#124}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#124}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U4224::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U4224::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#127}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#127}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#129}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#129}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U4352::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U4352::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#132}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#132}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#134}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#134}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U6144::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U6144::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#137}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#137}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#139}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#139}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U8192::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U8192::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#142}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#142}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.



impl Uint<crypto_bigint::::uint::{impl#144}::{constant#0}>

pub const fn concat( &self, lo: &Uint<crypto_bigint::::uint::{impl#144}::concat::{constant#0}>, ) -> Uint<crypto_bigint::::uint::U16384::{constant#0}>

Concatenate the two values, with self as most significant and rhs as the least significant.



impl Uint<crypto_bigint::::uint::U16384::{constant#0}>

pub const fn split( &self, ) -> (Uint<crypto_bigint::::uint::{impl#147}::split::{constant#0}>, Uint<crypto_bigint::::uint::{impl#147}::split::{constant#1}>)

Split this number in half, returning its high and low components respectively.