Add

Trait Add 

1.0.0 (const: unstable) · Source
pub trait Add<Rhs = Self> {
    type Output;

    // Required method
    fn add(self, rhs: Rhs) -> Self::Output;
}
The addition operator +.

Note that Rhs is Self by default, but this is not mandatory. For example, std::time::SystemTime implements Add<Duration>, which permits operations of the form SystemTime = SystemTime + Duration.

Examples

Addable points

use std::ops::Add;

#[derive(Debug, Copy, Clone, PartialEq)]
struct Point {
    x: i32,
    y: i32,
}

impl Add for Point {
    type Output = Self;

    fn add(self, other: Self) -> Self {
        Self {
            x: self.x + other.x,
            y: self.y + other.y,
        }
    }
}

assert_eq!(Point { x: 1, y: 0 } + Point { x: 2, y: 3 },
           Point { x: 3, y: 3 });

Implementing Add with generics

Here is an example of the same Point struct implementing the Add trait using generics.

use std::ops::Add;

#[derive(Debug, Copy, Clone, PartialEq)]
struct Point<T> {
    x: T,
    y: T,
}

// Notice that the implementation uses the associated type `Output`.
impl<T: Add<Output = T>> Add for Point<T> {
    type Output = Self;

    fn add(self, other: Self) -> Self::Output {
        Self {
            x: self.x + other.x,
            y: self.y + other.y,
        }
    }
}

assert_eq!(Point { x: 1, y: 0 } + Point { x: 2, y: 3 },
           Point { x: 3, y: 3 });

Required Associated Types

1.0.0 (const: unstable) · Source

type Output

The resulting type after applying the + operator.

Required Methods

1.0.0 (const: unstable) · Source

fn add(self, rhs: Rhs) -> Self::Output

Performs the + operation.

Example
assert_eq!(12 + 1, 13);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Add for ATerm

Source

impl Add for Assume

Source

impl Add for BigInt

Source

impl Add for BigUint



impl Add for Checked<Limb>

1.3.0 (const: unstable) · Source

impl Add for Duration



impl Add for Length



type Output = Result<Length, Error>



impl Add for airbender_crypto::k256::ProjectivePoint

1.74.0 (const: unstable) · Source

impl Add for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Add for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Add for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Add for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Add for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Add for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Add for Saturating<usize>



impl Add for airbender_crypto::k256::Scalar



impl Add for airbender_crypto::p256::Scalar

Source

impl Add for airbender_crypto::secp256k1::scalars::Scalar



impl Add for airbender_crypto::k256::elliptic_curve::bigint::Wrapping<Limb>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<i8>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<i16>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<i32>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<i64>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<i128>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<isize>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<u8>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<u16>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<u32>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<u64>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<u128>

1.0.0 (const: unstable) · Source

impl Add for core::num::wrapping::Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Add for f16

1.0.0 (const: unstable) · Source

impl Add for f32

1.0.0 (const: unstable) · Source

impl Add for f64

1.0.0 (const: unstable) · Source

impl Add for f128

1.0.0 (const: unstable) · Source

impl Add for i8

1.0.0 (const: unstable) · Source

impl Add for i16

1.0.0 (const: unstable) · Source

impl Add for i32

1.0.0 (const: unstable) · Source

impl Add for i64

1.0.0 (const: unstable) · Source

impl Add for i128

1.0.0 (const: unstable) · Source

impl Add for isize

1.0.0 (const: unstable) · Source

impl Add for u8

1.0.0 (const: unstable) · Source

impl Add for u16

1.0.0 (const: unstable) · Source

impl Add for u32

1.0.0 (const: unstable) · Source

impl Add for u64

1.0.0 (const: unstable) · Source

impl Add for u128

1.0.0 (const: unstable) · Source

impl Add for usize



impl Add<&AffinePoint> for &airbender_crypto::k256::ProjectivePoint



impl Add<&AffinePoint> for airbender_crypto::k256::ProjectivePoint

Source

impl Add<&BigInt> for &BigInt

Source

impl Add<&BigInt> for &i8

Source

impl Add<&BigInt> for &i16

Source

impl Add<&BigInt> for &i32

Source

impl Add<&BigInt> for &i64

Source

impl Add<&BigInt> for &i128

Source

impl Add<&BigInt> for &isize

Source

impl Add<&BigInt> for &u8

Source

impl Add<&BigInt> for &u16

Source

impl Add<&BigInt> for &u32

Source

impl Add<&BigInt> for &u64

Source

impl Add<&BigInt> for &u128

Source

impl Add<&BigInt> for &usize

Source

impl Add<&BigInt> for BigInt

Source

impl Add<&BigInt> for i8

Source

impl Add<&BigInt> for i16

Source

impl Add<&BigInt> for i32

Source

impl Add<&BigInt> for i64

Source

impl Add<&BigInt> for i128

Source

impl Add<&BigInt> for isize

Source

impl Add<&BigInt> for u8

Source

impl Add<&BigInt> for u16

Source

impl Add<&BigInt> for u32

Source

impl Add<&BigInt> for u64

Source

impl Add<&BigInt> for u128

Source

impl Add<&BigInt> for usize

Source

impl Add<&BigUint> for &BigUint

Source

impl Add<&BigUint> for &u8

Source

impl Add<&BigUint> for &u16

Source

impl Add<&BigUint> for &u32

Source

impl Add<&BigUint> for &u64

Source

impl Add<&BigUint> for &u128

Source

impl Add<&BigUint> for &usize

Source

impl Add<&BigUint> for BigUint

Source

impl Add<&BigUint> for u8

Source

impl Add<&BigUint> for u16

Source

impl Add<&BigUint> for u32

Source

impl Add<&BigUint> for u64

Source

impl Add<&BigUint> for u128

Source

impl Add<&BigUint> for usize



impl Add<&Checked<Limb>> for &Checked<Limb>



impl Add<&Checked<Limb>> for Checked<Limb>



impl Add<&ProjectivePoint> for &airbender_crypto::k256::ProjectivePoint



impl Add<&ProjectivePoint> for airbender_crypto::k256::ProjectivePoint

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i8>> for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i16>> for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i32>> for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i64>> for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i128>> for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<isize>> for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u8>> for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u16>> for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u32>> for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u64>> for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u128>> for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<usize>> for &Saturating<usize>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<usize>> for Saturating<usize>



impl Add<&Scalar> for &airbender_crypto::k256::Scalar



impl Add<&Scalar> for &airbender_crypto::p256::Scalar



impl Add<&Scalar> for airbender_crypto::k256::Scalar



impl Add<&Scalar> for airbender_crypto::p256::Scalar



impl Add<&Wrapping<Limb>> for &airbender_crypto::k256::elliptic_curve::bigint::Wrapping<Limb>



impl Add<&Wrapping<Limb>> for airbender_crypto::k256::elliptic_curve::bigint::Wrapping<Limb>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i8>> for &core::num::wrapping::Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i8>> for core::num::wrapping::Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i16>> for &core::num::wrapping::Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i16>> for core::num::wrapping::Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i32>> for &core::num::wrapping::Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i32>> for core::num::wrapping::Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i64>> for &core::num::wrapping::Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i64>> for core::num::wrapping::Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i128>> for &core::num::wrapping::Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i128>> for core::num::wrapping::Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<isize>> for &core::num::wrapping::Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<isize>> for core::num::wrapping::Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u8>> for &core::num::wrapping::Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u8>> for core::num::wrapping::Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u16>> for &core::num::wrapping::Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u16>> for core::num::wrapping::Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u32>> for &core::num::wrapping::Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u32>> for core::num::wrapping::Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u64>> for &core::num::wrapping::Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u64>> for core::num::wrapping::Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u128>> for &core::num::wrapping::Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u128>> for core::num::wrapping::Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<usize>> for &core::num::wrapping::Wrapping<usize>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<usize>> for core::num::wrapping::Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Add<&f16> for &f16

1.0.0 (const: unstable) · Source

impl Add<&f16> for f16

1.0.0 (const: unstable) · Source

impl Add<&f32> for &f32

1.0.0 (const: unstable) · Source

impl Add<&f32> for f32

1.0.0 (const: unstable) · Source

impl Add<&f64> for &f64

1.0.0 (const: unstable) · Source

impl Add<&f64> for f64

1.0.0 (const: unstable) · Source

impl Add<&f128> for &f128

1.0.0 (const: unstable) · Source

impl Add<&f128> for f128

Source

impl Add<&i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i8> for &i8

Source

impl Add<&i8> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i8> for i8

Source

impl Add<&i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i16> for &i16

Source

impl Add<&i16> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i16> for i16

Source

impl Add<&i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i32> for &i32

Source

impl Add<&i32> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i32> for i32

Source

impl Add<&i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i64> for &i64

Source

impl Add<&i64> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i64> for i64

Source

impl Add<&i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i128> for &i128

Source

impl Add<&i128> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i128> for i128

Source

impl Add<&isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&isize> for &isize

Source

impl Add<&isize> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&isize> for isize

1.0.0 · Source

impl Add<&str> for String

Available on non-no_global_oom_handling only.

Implements the + operator for concatenating two strings.

This consumes the String on the left-hand side and re-uses its buffer (growing it if necessary). This is done to avoid allocating a new String and copying the entire contents on every operation, which would lead to O(n^2) running time when building an n-byte string by repeated concatenation.

The string on the right-hand side is only borrowed; its contents are copied into the returned String.

Examples

Concatenating two Strings takes the first by value and borrows the second:

let a = String::from("hello");
let b = String::from(" world");
let c = a + &b;
// `a` is moved and can no longer be used here.

If you want to keep using the first String, you can clone it and append to the clone instead:

let a = String::from("hello");
let b = String::from(" world");
let c = a.clone() + &b;
// `a` is still valid here.

Concatenating &str slices can be done by converting the first to a String:

let a = "hello";
let b = " world";
let c = a.to_string() + b;
Source

impl Add<&u8> for &BigInt

Source

impl Add<&u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u8> for &u8

Source

impl Add<&u8> for BigInt

Source

impl Add<&u8> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u8> for u8

Source

impl Add<&u16> for &BigInt

Source

impl Add<&u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u16> for &u16

Source

impl Add<&u16> for BigInt

Source

impl Add<&u16> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u16> for u16

Source

impl Add<&u32> for &BigInt

Source

impl Add<&u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u32> for &u32

Source

impl Add<&u32> for BigInt

Source

impl Add<&u32> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u32> for u32

Source

impl Add<&u64> for &BigInt

Source

impl Add<&u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u64> for &u64

Source

impl Add<&u64> for BigInt

Source

impl Add<&u64> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u64> for u64

Source

impl Add<&u128> for &BigInt

Source

impl Add<&u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u128> for &u128

Source

impl Add<&u128> for BigInt

Source

impl Add<&u128> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u128> for u128

Source

impl Add<&usize> for &BigInt

Source

impl Add<&usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&usize> for &usize

Source

impl Add<&usize> for BigInt

Source

impl Add<&usize> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&usize> for usize



impl Add<AffinePoint> for airbender_crypto::k256::ProjectivePoint

Source

impl Add<B0> for UTerm

UTerm + B0 = UTerm

Source

impl Add<B1> for UTerm

UTerm + B1 = UInt<UTerm, B1>

Source

impl Add<BigInt> for &BigInt

Source

impl Add<BigInt> for &i8

Source

impl Add<BigInt> for &i16

Source

impl Add<BigInt> for &i32

Source

impl Add<BigInt> for &i64

Source

impl Add<BigInt> for &i128

Source

impl Add<BigInt> for &isize

Source

impl Add<BigInt> for &u8

Source

impl Add<BigInt> for &u16

Source

impl Add<BigInt> for &u32

Source

impl Add<BigInt> for &u64

Source

impl Add<BigInt> for &u128

Source

impl Add<BigInt> for &usize

Source

impl Add<BigInt> for i8

Source

impl Add<BigInt> for i16

Source

impl Add<BigInt> for i32

Source

impl Add<BigInt> for i64

Source

impl Add<BigInt> for i128

Source

impl Add<BigInt> for isize

Source

impl Add<BigInt> for u8

Source

impl Add<BigInt> for u16

Source

impl Add<BigInt> for u32

Source

impl Add<BigInt> for u64

Source

impl Add<BigInt> for u128

Source

impl Add<BigInt> for usize

Source

impl Add<BigUint> for &BigUint

Source

impl Add<BigUint> for &u8

Source

impl Add<BigUint> for &u16

Source

impl Add<BigUint> for &u32

Source

impl Add<BigUint> for &u64

Source

impl Add<BigUint> for &u128

Source

impl Add<BigUint> for &usize

Source

impl Add<BigUint> for u8

Source

impl Add<BigUint> for u16

Source

impl Add<BigUint> for u32

Source

impl Add<BigUint> for u64

Source

impl Add<BigUint> for u128

Source

impl Add<BigUint> for usize



impl Add<Checked<Limb>> for &Checked<Limb>

1.8.0 · Source

impl Add<Duration> for Instant

1.8.0 · Source

impl Add<Duration> for SystemTime



impl Add<Length> for Result<Length, Error>



type Output = Result<Length, Error>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Add<Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Add<Saturating<usize>> for &Saturating<usize>



impl Add<Scalar> for &airbender_crypto::k256::Scalar



impl Add<Wrapping<Limb>> for &airbender_crypto::k256::elliptic_curve::bigint::Wrapping<Limb>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i8>> for &core::num::wrapping::Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i16>> for &core::num::wrapping::Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i32>> for &core::num::wrapping::Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i64>> for &core::num::wrapping::Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i128>> for &core::num::wrapping::Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<isize>> for &core::num::wrapping::Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u8>> for &core::num::wrapping::Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u16>> for &core::num::wrapping::Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u32>> for &core::num::wrapping::Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u64>> for &core::num::wrapping::Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u128>> for &core::num::wrapping::Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<usize>> for &core::num::wrapping::Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Add<f16> for &f16

1.0.0 (const: unstable) · Source

impl Add<f32> for &f32

1.0.0 (const: unstable) · Source

impl Add<f64> for &f64

1.0.0 (const: unstable) · Source

impl Add<f128> for &f128

Source

impl Add<i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i8> for &i8

Source

impl Add<i8> for BigInt

Source

impl Add<i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i16> for &i16

Source

impl Add<i16> for BigInt

Source

impl Add<i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i32> for &i32

Source

impl Add<i32> for BigInt

Source

impl Add<i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i64> for &i64

Source

impl Add<i64> for BigInt

Source

impl Add<i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i128> for &i128

Source

impl Add<i128> for BigInt

Source

impl Add<isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<isize> for &isize

Source

impl Add<isize> for BigInt

Source

impl Add<u8> for &BigInt

Source

impl Add<u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u8> for &u8

Source

impl Add<u8> for BigInt

Source

impl Add<u8> for BigUint



impl Add<u8> for Length



type Output = Result<Length, Error>

Source

impl Add<u16> for &BigInt

Source

impl Add<u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u16> for &u16

Source

impl Add<u16> for BigInt

Source

impl Add<u16> for BigUint



impl Add<u16> for Length



type Output = Result<Length, Error>

Source

impl Add<u32> for &BigInt

Source

impl Add<u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u32> for &u32

Source

impl Add<u32> for BigInt

Source

impl Add<u32> for BigUint



impl Add<u32> for Length



type Output = Result<Length, Error>

Source

impl Add<u64> for &BigInt

Source

impl Add<u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u64> for &u64

Source

impl Add<u64> for BigInt

Source

impl Add<u64> for BigUint

Source

impl Add<u128> for &BigInt

Source

impl Add<u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u128> for &u128

Source

impl Add<u128> for BigInt

Source

impl Add<u128> for BigUint

Source

impl Add<usize> for &BigInt

Source

impl Add<usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<usize> for &usize

Source

impl Add<usize> for BigInt

Source

impl Add<usize> for BigUint



impl Add<usize> for Length



type Output = Result<Length, Error>



impl<'a, 'b, F, D> Add<&'a Evaluations<F, D>> for &'b Evaluations<F, D>
where F: FftField, D: EvaluationDomain<F>,



type Output = Evaluations<F, D>



impl<'a, 'b, F, T> Add<&'a SparsePolynomial<F, T>> for &'b SparsePolynomial<F, T>
where F: Field, T: Term,



type Output = SparsePolynomial<F, T>



impl<'a, 'b, F> Add<&'a DenseMultilinearExtension<F>> for &'b DenseMultilinearExtension<F>
where F: Field,



type Output = DenseMultilinearExtension<F>



impl<'a, 'b, F> Add<&'a DensePolynomial<F>> for &'b DensePolynomial<F>
where F: Field,



type Output = DensePolynomial<F>



impl<'a, 'b, F> Add<&'a SparseMultilinearExtension<F>> for &'b SparseMultilinearExtension<F>
where F: Field,



type Output = SparseMultilinearExtension<F>



impl<'a, 'b, F> Add<&'a SparsePolynomial<F>> for &'b DensePolynomial<F>
where F: Field,



type Output = DensePolynomial<F>



impl<'a, 'b, F> Add<&'a SparsePolynomial<F>> for &'b SparsePolynomial<F>
where F: Field,



type Output = SparsePolynomial<F>



impl<'a, 'b, P, const N: usize> Add<&'b Fp<P, N>> for &'a Fp<P, N>
where P: FpConfig<N>,



type Output = Fp<P, N>



impl<'a, 'b, P> Add<&'a CubicExtField<P>> for &'b CubicExtField<P>
where P: CubicExtConfig,



type Output = CubicExtField<P>



impl<'a, 'b, P> Add<&'a PairingOutput<P>> for &'b PairingOutput<P>
where P: Pairing,



type Output = PairingOutput<P>



impl<'a, 'b, P> Add<&'a Projective<P>> for &'b Projective<P>
where P: SWCurveConfig,



type Output = Projective<P>



impl<'a, 'b, P> Add<&'a Projective<P>> for &'b Projective<P>
where P: TECurveConfig,



type Output = Projective<P>



impl<'a, 'b, P> Add<&'a QuadExtField<P>> for &'b QuadExtField<P>
where P: QuadExtConfig,



type Output = QuadExtField<P>



impl<'a, 'b, P> Add<&'a mut CubicExtField<P>> for &'b CubicExtField<P>
where P: CubicExtConfig,



type Output = CubicExtField<P>



impl<'a, 'b, P> Add<&'a mut PairingOutput<P>> for &'b PairingOutput<P>
where P: Pairing,



type Output = PairingOutput<P>



impl<'a, 'b, P> Add<&'a mut Projective<P>> for &'b Projective<P>
where P: SWCurveConfig,



type Output = Projective<P>



impl<'a, 'b, P> Add<&'a mut Projective<P>> for &'b Projective<P>
where P: TECurveConfig,



type Output = Projective<P>



impl<'a, 'b, P> Add<&'a mut QuadExtField<P>> for &'b QuadExtField<P>
where P: QuadExtConfig,



type Output = QuadExtField<P>



impl<'a, F> Add<&'a DensePolynomial<F>> for DensePolynomial<F>
where F: Field,



type Output = DensePolynomial<F>



impl<'a, F> Add<DensePolynomial<F>> for &'a DensePolynomial<F>
where F: Field,



type Output = DensePolynomial<F>



impl<'a, P, const N: usize> Add<&'a Fp<P, N>> for Fp<P, N>
where P: FpConfig<N>,



type Output = Fp<P, N>



impl<'a, P, const N: usize> Add<&'a mut Fp<P, N>> for Fp<P, N>
where P: FpConfig<N>,



type Output = Fp<P, N>



impl<'a, P> Add<&'a CubicExtField<P>> for CubicExtField<P>
where P: CubicExtConfig,



type Output = CubicExtField<P>



impl<'a, P> Add<&'a PairingOutput<P>> for PairingOutput<P>
where P: Pairing,



type Output = PairingOutput<P>



impl<'a, P> Add<&'a Projective<P>> for Affine<P>
where P: SWCurveConfig,



type Output = Projective<P>



impl<'a, P> Add<&'a Projective<P>> for Affine<P>
where P: TECurveConfig,



type Output = Projective<P>



impl<'a, P> Add<&'a Projective<P>> for Projective<P>
where P: SWCurveConfig,



type Output = Projective<P>



impl<'a, P> Add<&'a Projective<P>> for Projective<P>
where P: TECurveConfig,



type Output = Projective<P>



impl<'a, P> Add<&'a QuadExtField<P>> for QuadExtField<P>
where P: QuadExtConfig,



type Output = QuadExtField<P>



impl<'a, P> Add<&'a mut CubicExtField<P>> for CubicExtField<P>
where P: CubicExtConfig,



type Output = CubicExtField<P>



impl<'a, P> Add<&'a mut PairingOutput<P>> for PairingOutput<P>
where P: Pairing,



type Output = PairingOutput<P>



impl<'a, P> Add<&'a mut Projective<P>> for Projective<P>
where P: SWCurveConfig,



type Output = Projective<P>



impl<'a, P> Add<&'a mut Projective<P>> for Projective<P>
where P: TECurveConfig,



type Output = Projective<P>



impl<'a, P> Add<&'a mut QuadExtField<P>> for QuadExtField<P>
where P: QuadExtConfig,



type Output = QuadExtField<P>

1.14.0 · Source

impl<'a> Add for Cow<'a, str>

Available on non-no_global_oom_handling only.
Source

type Output = Cow<'a, str>

1.14.0 · Source

impl<'a> Add<&'a str> for Cow<'a, str>

Available on non-no_global_oom_handling only.
Source

type Output = Cow<'a, str>



impl<'b, P> Add<CubicExtField<P>> for &'b CubicExtField<P>
where P: CubicExtConfig,



type Output = CubicExtField<P>



impl<'b, P> Add<PairingOutput<P>> for &'b PairingOutput<P>
where P: Pairing,



type Output = PairingOutput<P>



impl<'b, P> Add<Projective<P>> for &'b Projective<P>
where P: SWCurveConfig,



type Output = Projective<P>



impl<'b, P> Add<Projective<P>> for &'b Projective<P>
where P: TECurveConfig,



type Output = Projective<P>



impl<'b, P> Add<QuadExtField<P>> for &'b QuadExtField<P>
where P: QuadExtConfig,



type Output = QuadExtField<P>

Source

impl<'lhs, 'rhs, T, const N: usize> Add<&'rhs Simd<T, N>> for &'lhs Simd<T, N>
where T: SimdElement, Simd<T, N>: Add<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<Al, Vl, Ar, Vr> Add<TArr<Vr, Ar>> for TArr<Vl, Al>
where Al: Add<Ar>, Vl: Add<Vr>,

Source

type Output = TArr<<Vl as Add<Vr>>::Output, <Al as Add<Ar>>::Output>



impl<C> Add for ProjectivePoint<C>
where C: PrimeCurveParams,



type Output = ProjectivePoint<C>



impl<C> Add for ScalarPrimitive<C>
where C: Curve,



impl<C> Add<&AffinePoint<C>> for &ProjectivePoint<C>
where C: PrimeCurveParams,



type Output = ProjectivePoint<C>



impl<C> Add<&AffinePoint<C>> for ProjectivePoint<C>
where C: PrimeCurveParams,



type Output = ProjectivePoint<C>



impl<C> Add<&ProjectivePoint<C>> for &ProjectivePoint<C>
where C: PrimeCurveParams,



type Output = ProjectivePoint<C>



impl<C> Add<&ProjectivePoint<C>> for ProjectivePoint<C>
where C: PrimeCurveParams,



type Output = ProjectivePoint<C>



impl<C> Add<&ScalarPrimitive<C>> for ScalarPrimitive<C>
where C: Curve,



impl<C> Add<AffinePoint<C>> for ProjectivePoint<C>
where C: PrimeCurveParams,



type Output = ProjectivePoint<C>



impl<F, T> Add for SparsePolynomial<F, T>
where F: Field, T: Term,



type Output = SparsePolynomial<F, T>



impl<F> Add for DenseMultilinearExtension<F>
where F: Field,



type Output = DenseMultilinearExtension<F>



impl<F> Add for DensePolynomial<F>
where F: Field,



type Output = DensePolynomial<F>



impl<F> Add for SparseMultilinearExtension<F>
where F: Field,



type Output = SparseMultilinearExtension<F>



impl<F> Add for SparsePolynomial<F>
where F: Field,



type Output = SparsePolynomial<F>

Source

impl<I> Add<I> for Z0
where I: Integer,

Z0 + I = I



impl<MOD, const LIMBS: usize> Add for Residue<MOD, LIMBS>
where MOD: ResidueParams<LIMBS>,



type Output = Residue<MOD, LIMBS>



impl<MOD, const LIMBS: usize> Add<&Residue<MOD, LIMBS>> for &Residue<MOD, LIMBS>
where MOD: ResidueParams<LIMBS>,



type Output = Residue<MOD, LIMBS>



impl<MOD, const LIMBS: usize> Add<&Residue<MOD, LIMBS>> for Residue<MOD, LIMBS>
where MOD: ResidueParams<LIMBS>,



type Output = Residue<MOD, LIMBS>



impl<MOD, const LIMBS: usize> Add<Residue<MOD, LIMBS>> for &Residue<MOD, LIMBS>
where MOD: ResidueParams<LIMBS>,



type Output = Residue<MOD, LIMBS>



impl<O> Add for F32<O>
where O: ByteOrder,



type Output = F32<O>



impl<O> Add for F64<O>
where O: ByteOrder,



type Output = F64<O>



impl<O> Add for I16<O>
where O: ByteOrder,



type Output = I16<O>



impl<O> Add for I32<O>
where O: ByteOrder,



type Output = I32<O>



impl<O> Add for I64<O>
where O: ByteOrder,



type Output = I64<O>



impl<O> Add for I128<O>
where O: ByteOrder,



type Output = I128<O>



impl<O> Add for Isize<O>
where O: ByteOrder,



type Output = Isize<O>



impl<O> Add for U16<O>
where O: ByteOrder,



type Output = U16<O>



impl<O> Add for U32<O>
where O: ByteOrder,



type Output = U32<O>



impl<O> Add for U64<O>
where O: ByteOrder,



type Output = U64<O>



impl<O> Add for U128<O>
where O: ByteOrder,



type Output = U128<O>



impl<O> Add for Usize<O>
where O: ByteOrder,



type Output = Usize<O>



impl<O> Add<F32<O>> for f32
where O: ByteOrder,



type Output = F32<O>



impl<O> Add<F64<O>> for f64
where O: ByteOrder,



type Output = F64<O>



impl<O> Add<I16<O>> for i16
where O: ByteOrder,



type Output = I16<O>



impl<O> Add<I32<O>> for i32
where O: ByteOrder,



type Output = I32<O>



impl<O> Add<I64<O>> for i64
where O: ByteOrder,



type Output = I64<O>



impl<O> Add<I128<O>> for i128
where O: ByteOrder,



type Output = I128<O>



impl<O> Add<Isize<O>> for isize
where O: ByteOrder,



type Output = Isize<O>



impl<O> Add<U16<O>> for u16
where O: ByteOrder,



type Output = U16<O>



impl<O> Add<U32<O>> for u32
where O: ByteOrder,



type Output = U32<O>



impl<O> Add<U64<O>> for u64
where O: ByteOrder,



type Output = U64<O>



impl<O> Add<U128<O>> for u128
where O: ByteOrder,



type Output = U128<O>



impl<O> Add<Usize<O>> for usize
where O: ByteOrder,



type Output = Usize<O>



impl<O> Add<f32> for F32<O>
where O: ByteOrder,



type Output = F32<O>



impl<O> Add<f64> for F64<O>
where O: ByteOrder,



type Output = F64<O>



impl<O> Add<i16> for I16<O>
where O: ByteOrder,



type Output = I16<O>



impl<O> Add<i32> for I32<O>
where O: ByteOrder,



type Output = I32<O>



impl<O> Add<i64> for I64<O>
where O: ByteOrder,



type Output = I64<O>



impl<O> Add<i128> for I128<O>
where O: ByteOrder,



type Output = I128<O>



impl<O> Add<isize> for Isize<O>
where O: ByteOrder,



type Output = Isize<O>



impl<O> Add<u16> for U16<O>
where O: ByteOrder,



type Output = U16<O>



impl<O> Add<u32> for U32<O>
where O: ByteOrder,



type Output = U32<O>



impl<O> Add<u64> for U64<O>
where O: ByteOrder,



type Output = U64<O>



impl<O> Add<u128> for U128<O>
where O: ByteOrder,



type Output = U128<O>



impl<O> Add<usize> for Usize<O>
where O: ByteOrder,



type Output = Usize<O>



impl<P, T> Add<T> for Affine<P>
where P: SWCurveConfig, T: Borrow<Affine<P>>,



type Output = Projective<P>



impl<P, T> Add<T> for Affine<P>
where P: TECurveConfig, T: Borrow<Affine<P>>,



type Output = Projective<P>



impl<P, T> Add<T> for Projective<P>
where P: SWCurveConfig, T: Borrow<Affine<P>>,



type Output = Projective<P>



impl<P, T> Add<T> for Projective<P>
where P: TECurveConfig, T: Borrow<Affine<P>>,



type Output = Projective<P>



impl<P, const N: usize> Add for Fp<P, N>
where P: FpConfig<N>,



type Output = Fp<P, N>



impl<P> Add for CubicExtField<P>
where P: CubicExtConfig,



type Output = CubicExtField<P>



impl<P> Add for PairingOutput<P>
where P: Pairing,



type Output = PairingOutput<P>



impl<P> Add for Projective<P>
where P: SWCurveConfig,



type Output = Projective<P>



impl<P> Add for Projective<P>
where P: TECurveConfig,



type Output = Projective<P>



impl<P> Add for QuadExtField<P>
where P: QuadExtConfig,



type Output = QuadExtField<P>



impl<P> Add<Projective<P>> for Affine<P>
where P: SWCurveConfig,



type Output = Projective<P>



impl<P> Add<Projective<P>> for Affine<P>
where P: TECurveConfig,



type Output = Projective<P>

Source

impl<T, const N: usize> Add<&Simd<T, N>> for Simd<T, N>
where T: SimdElement, Simd<T, N>: Add<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<T, const N: usize> Add<Simd<T, N>> for &Simd<T, N>
where T: SimdElement, Simd<T, N>: Add<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<U, B> Add<B0> for UInt<U, B>
where U: Unsigned, B: Bit,

U + B0 = U

Source

type Output = UInt<U, B>

Source

impl<U, B> Add<UTerm> for UInt<U, B>
where U: Unsigned, B: Bit,

UInt<U, B> + UTerm = UInt<U, B>

Source

type Output = UInt<U, B>

Source

impl<U> Add<B1> for UInt<U, B0>
where U: Unsigned,

UInt<U, B0> + B1 = UInt<U + B1>

Source

impl<U> Add<B1> for UInt<U, B1>
where U: Unsigned + Add<B1>, <U as Add<B1>>::Output: Unsigned,

UInt<U, B1> + B1 = UInt<U + B1, B0>

Source

type Output = UInt<<U as Add<B1>>::Output, B0>

Source

impl<U> Add<U> for UTerm
where U: Unsigned,

UTerm + U = U

Source

impl<U> Add<Z0> for NInt<U>
where U: Unsigned + NonZero,

NInt + Z0 = NInt

Source

impl<U> Add<Z0> for PInt<U>
where U: Unsigned + NonZero,

PInt + Z0 = PInt

Source

impl<Ul, Ur> Add<NInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero + Add<Ur>, Ur: Unsigned + NonZero, <Ul as Add<Ur>>::Output: Unsigned + NonZero,

N(Ul) + N(Ur) = N(Ul + Ur)

Source

type Output = NInt<<Ul as Add<Ur>>::Output>

Source

impl<Ul, Ur> Add<NInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Cmp<Ur> + PrivateIntegerAdd<<Ul as Cmp<Ur>>::Output, Ur>, Ur: Unsigned + NonZero,

P(Ul) + N(Ur): We resolve this with our PrivateAdd

Source

type Output = <Ul as PrivateIntegerAdd<<Ul as Cmp<Ur>>::Output, Ur>>::Output

Source

impl<Ul, Ur> Add<PInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero, Ur: Unsigned + NonZero + Cmp<Ul> + PrivateIntegerAdd<<Ur as Cmp<Ul>>::Output, Ul>,

N(Ul) + P(Ur): We resolve this with our PrivateAdd

Source

type Output = <Ur as PrivateIntegerAdd<<Ur as Cmp<Ul>>::Output, Ul>>::Output

Source

impl<Ul, Ur> Add<PInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Add<Ur>, Ur: Unsigned + NonZero, <Ul as Add<Ur>>::Output: Unsigned + NonZero,

P(Ul) + P(Ur) = P(Ul + Ur)

Source

type Output = PInt<<Ul as Add<Ur>>::Output>

Source

impl<Ul, Ur> Add<UInt<Ur, B0>> for UInt<Ul, B0>
where Ul: Unsigned + Add<Ur>, Ur: Unsigned,

UInt<Ul, B0> + UInt<Ur, B0> = UInt<Ul + Ur, B0>

Source

type Output = UInt<<Ul as Add<Ur>>::Output, B0>

Source

impl<Ul, Ur> Add<UInt<Ur, B0>> for UInt<Ul, B1>
where Ul: Unsigned + Add<Ur>, Ur: Unsigned,

UInt<Ul, B1> + UInt<Ur, B0> = UInt<Ul + Ur, B1>

Source

type Output = UInt<<Ul as Add<Ur>>::Output, B1>

Source

impl<Ul, Ur> Add<UInt<Ur, B1>> for UInt<Ul, B0>
where Ul: Unsigned + Add<Ur>, Ur: Unsigned,

UInt<Ul, B0> + UInt<Ur, B1> = UInt<Ul + Ur, B1>

Source

type Output = UInt<<Ul as Add<Ur>>::Output, B1>

Source

impl<Ul, Ur> Add<UInt<Ur, B1>> for UInt<Ul, B1>
where Ul: Unsigned + Add<Ur>, Ur: Unsigned, <Ul as Add<Ur>>::Output: Add<B1>,

UInt<Ul, B1> + UInt<Ur, B1> = UInt<(Ul + Ur) + B1, B0>

Source

type Output = UInt<<<Ul as Add<Ur>>::Output as Add<B1>>::Output, B0>



impl<const BITS: usize, const LIMBS: usize> Add for Uint<BITS, LIMBS>



type Output = Uint<BITS, LIMBS>



impl<const BITS: usize, const LIMBS: usize> Add<&Uint<BITS, LIMBS>> for &Uint<BITS, LIMBS>



type Output = Uint<BITS, LIMBS>



impl<const BITS: usize, const LIMBS: usize> Add<&Uint<BITS, LIMBS>> for Uint<BITS, LIMBS>



type Output = Uint<BITS, LIMBS>



impl<const BITS: usize, const LIMBS: usize> Add<Uint<BITS, LIMBS>> for &Uint<BITS, LIMBS>



type Output = Uint<BITS, LIMBS>



impl<const LIMBS: usize> Add for Checked<Uint<LIMBS>>



type Output = Checked<Uint<LIMBS>>



impl<const LIMBS: usize> Add for DynResidue<LIMBS>



type Output = DynResidue<LIMBS>



impl<const LIMBS: usize> Add for airbender_crypto::k256::elliptic_curve::bigint::Wrapping<Uint<LIMBS>>



type Output = Wrapping<Uint<LIMBS>>



impl<const LIMBS: usize> Add<&Checked<Uint<LIMBS>>> for &Checked<Uint<LIMBS>>



type Output = Checked<Uint<LIMBS>>



impl<const LIMBS: usize> Add<&Checked<Uint<LIMBS>>> for Checked<Uint<LIMBS>>



type Output = Checked<Uint<LIMBS>>



impl<const LIMBS: usize> Add<&DynResidue<LIMBS>> for &DynResidue<LIMBS>



type Output = DynResidue<LIMBS>



impl<const LIMBS: usize> Add<&DynResidue<LIMBS>> for DynResidue<LIMBS>



type Output = DynResidue<LIMBS>



impl<const LIMBS: usize> Add<&Wrapping<Uint<LIMBS>>> for &airbender_crypto::k256::elliptic_curve::bigint::Wrapping<Uint<LIMBS>>



type Output = Wrapping<Uint<LIMBS>>



impl<const LIMBS: usize> Add<&Wrapping<Uint<LIMBS>>> for airbender_crypto::k256::elliptic_curve::bigint::Wrapping<Uint<LIMBS>>



type Output = Wrapping<Uint<LIMBS>>



impl<const LIMBS: usize> Add<Checked<Uint<LIMBS>>> for &Checked<Uint<LIMBS>>



type Output = Checked<Uint<LIMBS>>



impl<const LIMBS: usize> Add<DynResidue<LIMBS>> for &DynResidue<LIMBS>



type Output = DynResidue<LIMBS>



impl<const LIMBS: usize> Add<Wrapping<Uint<LIMBS>>> for &airbender_crypto::k256::elliptic_curve::bigint::Wrapping<Uint<LIMBS>>



type Output = Wrapping<Uint<LIMBS>>

Source

impl<const N: usize> Add for Simd<f16, N>

Source

impl<const N: usize> Add for Simd<f32, N>

Source

impl<const N: usize> Add for Simd<f64, N>

Source

impl<const N: usize> Add for Simd<i8, N>
where i8: SimdElement,

Source

impl<const N: usize> Add for Simd<i16, N>

Source

impl<const N: usize> Add for Simd<i32, N>

Source

impl<const N: usize> Add for Simd<i64, N>

Source

impl<const N: usize> Add for Simd<isize, N>

Source

impl<const N: usize> Add for Simd<u8, N>
where u8: SimdElement,

Source

impl<const N: usize> Add for Simd<u16, N>

Source

impl<const N: usize> Add for Simd<u32, N>

Source

impl<const N: usize> Add for Simd<u64, N>

Source

impl<const N: usize> Add for Simd<usize, N>