Struct BlindedScalar
pub struct BlindedScalar<C>where
C: CurveArithmetic,{ /* private fields */ }Expand description
Scalar blinded with a randomly generated masking value.
This provides a randomly blinded impl of Invert which is useful for
e.g. ECDSA ephemeral (k) scalars.
It implements masked variable-time inversions using Stein’s algorithm, which may be helpful for performance on embedded platforms.
Implementations
impl<C> BlindedScalar<C>where
C: CurveArithmetic,
impl<C> BlindedScalar<C>where
C: CurveArithmetic,
pub fn new(
scalar: <C as CurveArithmetic>::Scalar,
rng: &mut impl CryptoRngCore,
) -> BlindedScalar<C>
pub fn new( scalar: <C as CurveArithmetic>::Scalar, rng: &mut impl CryptoRngCore, ) -> BlindedScalar<C>
Create a new BlindedScalar from a scalar and a CryptoRngCore.