Enum Coordinates
pub enum Coordinates<'a, Size>where
Size: ModulusSize,{
Identity,
Compact {
x: &'a GenericArray<u8, Size>,
},
Compressed {
x: &'a GenericArray<u8, Size>,
y_is_odd: bool,
},
Uncompressed {
x: &'a GenericArray<u8, Size>,
y: &'a GenericArray<u8, Size>,
},
}Expand description
Enum representing the coordinates of either compressed or uncompressed SEC1-encoded elliptic curve points.
Variants
Identity
Identity point (a.k.a. point at infinity)
Compact
Compact curve point
Fields

x: &'a GenericArray<u8, Size>x-coordinate
Compressed
Compressed curve point
Uncompressed
Uncompressed curve point
Implementations
impl<'a, Size> Coordinates<'a, Size>where
Size: ModulusSize,
impl<'a, Size> Coordinates<'a, Size>where
Size: ModulusSize,
pub fn tag(&self) -> Tag
pub fn tag(&self) -> Tag
Get the tag octet needed to encode this set of Coordinates