Struct Limb
#[repr(transparent)]pub struct Limb(pub u64);Expand description
Big integers are represented as an array of smaller CPU word-size integers called “limbs”.
Tuple Fields
0: u64Implementations
impl Limb
impl Limb
pub const fn adc(self, rhs: Limb, carry: Limb) -> (Limb, Limb)
pub const fn adc(self, rhs: Limb, carry: Limb) -> (Limb, Limb)
Computes self + rhs + carry, returning the result along with the new carry.
pub const fn saturating_add(&self, rhs: Limb) -> Limb
pub const fn saturating_add(&self, rhs: Limb) -> Limb
Perform saturating addition.
pub const fn wrapping_add(&self, rhs: Limb) -> Limb
pub const fn wrapping_add(&self, rhs: Limb) -> Limb
Perform wrapping addition, discarding overflow.
impl Limb
impl Limb
pub const fn leading_zeros(self) -> usize
pub const fn leading_zeros(self) -> usize
Calculate the number of leading zeros in the binary representation of this number.
pub const fn trailing_zeros(self) -> usize
pub const fn trailing_zeros(self) -> usize
Calculate the number of trailing zeros in the binary representation of this number.
pub const fn trailing_ones(self) -> usize
pub const fn trailing_ones(self) -> usize
Calculate the number of trailing ones the binary representation of this number.
impl Limb
impl Limb
pub fn cmp_vartime(&self, other: &Limb) -> Ordering
pub fn cmp_vartime(&self, other: &Limb) -> Ordering
Perform a comparison of the inner value in variable-time.
Note that the PartialOrd and Ord impls wrap constant-time
comparisons using the subtle crate.
pub const fn eq_vartime(&self, other: &Limb) -> bool
pub const fn eq_vartime(&self, other: &Limb) -> bool
Performs an equality check in variable-time.
impl Limb
impl Limb
pub const fn mac(self, b: Limb, c: Limb, carry: Limb) -> (Limb, Limb)
pub const fn mac(self, b: Limb, c: Limb, carry: Limb) -> (Limb, Limb)
Computes self + (b * c) + carry, returning the result along with the new carry.
pub const fn saturating_mul(&self, rhs: Limb) -> Limb
pub const fn saturating_mul(&self, rhs: Limb) -> Limb
Perform saturating multiplication.
pub const fn wrapping_mul(&self, rhs: Limb) -> Limb
pub const fn wrapping_mul(&self, rhs: Limb) -> Limb
Perform wrapping multiplication, discarding overflow.
impl Limb
impl Limb
pub const fn wrapping_neg(self) -> Limb
pub const fn wrapping_neg(self) -> Limb
Perform wrapping negation.
impl Limb
impl Limb
pub const fn sbb(self, rhs: Limb, borrow: Limb) -> (Limb, Limb)
pub const fn sbb(self, rhs: Limb, borrow: Limb) -> (Limb, Limb)
Computes self - (rhs + borrow), returning the result along with the new borrow.
pub const fn saturating_sub(&self, rhs: Limb) -> Limb
pub const fn saturating_sub(&self, rhs: Limb) -> Limb
Perform saturating subtraction.
pub const fn wrapping_sub(&self, rhs: Limb) -> Limb
pub const fn wrapping_sub(&self, rhs: Limb) -> Limb
Perform wrapping subtraction, discarding underflow and wrapping around the boundary of the type.