Struct Scalar
pub struct Scalar(/* private fields */);Expand description
Scalars are elements in the finite field modulo n.
Trait impls
Much of the important functionality of scalars is provided by traits from
the ff crate, which is re-exported as
p256::elliptic_curve::ff:
Field- represents elements of finite fields and provides:Field::random- generate a random scalardouble,square, andinvertoperations- Bounds for
Add,Sub,Mul, andNeg(as well as*Assignequivalents) - Bounds for
ConditionallySelectablefrom thesubtlecrate
PrimeField- represents elements of prime fields and provides:from_repr/to_reprfor converting field elements from/to big integers.multiplicative_generatorandroot_of_unityconstants.
PrimeFieldBits- operations over field elements represented as bits (requiresbitsfeature)
Please see the documentation for the relevant traits for more information.
serde support
When the serde feature of this crate is enabled, the Serialize and
Deserialize traits are impl’d for this type.
The serialization is a fixed-width big endian encoding. When used with textual formats, the binary data is encoded as hexadecimal.
Implementations
impl Scalar
impl Scalar
pub fn to_bytes(&self) -> GenericArray<u8, <NistP256 as Curve>::FieldBytesSize>
pub fn to_bytes(&self) -> GenericArray<u8, <NistP256 as Curve>::FieldBytesSize>
Returns the SEC1 encoding of this scalar.
pub const fn shr_vartime(&self, shift: usize) -> Scalar
pub const fn shr_vartime(&self, shift: usize) -> Scalar
Right shifts the scalar.
Note: not constant-time with respect to the shift parameter.
pub fn invert(&self) -> CtOption<Scalar>
pub fn invert(&self) -> CtOption<Scalar>
Returns the multiplicative inverse of self, if self is non-zero
pub const fn pow_vartime(&self, exp: &[u64]) -> Scalar
pub const fn pow_vartime(&self, exp: &[u64]) -> Scalar
Exponentiates self by exp, where exp is a little-endian order integer
exponent.