Trait ArrayLength
pub unsafe trait ArrayLength<T>: Unsigned {
type ArrayType;
}👎Deprecated:
please upgrade to generic-array 1.x
Trait making GenericArray work, marking types to be used as length of an array
Required Associated Types
type ArrayType
👎Deprecated: please upgrade to generic-array 1.x
type ArrayType
please upgrade to generic-array 1.x
Associated type representing the array type for the number
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".