Trait BatchInvert
pub trait BatchInvert<FieldElements>: Sized + Invertwhere
FieldElements: ?Sized,{
type Output: AsRef<[Self]>;
// Required method
fn batch_invert(field_elements: &FieldElements) -> CtOption<Self::Output>;
}Expand description
Perform a batched inversion on a sequence of field elements (i.e. base field elements or scalars) at an amortized cost that should be practically as efficient as a single inversion.
Required Associated Types
Required Methods
fn batch_invert(field_elements: &FieldElements) -> CtOption<Self::Output>
fn batch_invert(field_elements: &FieldElements) -> CtOption<Self::Output>
Invert a batch of field elements.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.