Struct ProjectivePoint
pub struct ProjectivePoint { /* private fields */ }Expand description
A point on the secp256k1 curve in projective coordinates.
Implementations
impl ProjectivePoint
impl ProjectivePoint
pub const IDENTITY: ProjectivePoint
pub const IDENTITY: ProjectivePoint
Additive identity of the group: the point at infinity.
pub const GENERATOR: ProjectivePoint
pub const GENERATOR: ProjectivePoint
Base point of secp256k1.
pub const fn identity() -> ProjectivePoint
👎Deprecated since 0.10.2: use ProjectivePoint::IDENTITY instead
pub const fn identity() -> ProjectivePoint
ProjectivePoint::IDENTITY insteadReturns the additive identity of SECP256k1, also known as the “neutral element” or “point at infinity”.
pub fn generator() -> ProjectivePoint
👎Deprecated since 0.10.2: use ProjectivePoint::GENERATOR instead
pub fn generator() -> ProjectivePoint
ProjectivePoint::GENERATOR insteadReturns the base point of SECP256k1.
pub fn to_affine(&self) -> AffinePoint
pub fn to_affine(&self) -> AffinePoint
Returns the affine representation of this point.
pub fn double(&self) -> ProjectivePoint
pub fn double(&self) -> ProjectivePoint
Doubles this point.
pub fn endomorphism(&self) -> ProjectivePoint
pub fn endomorphism(&self) -> ProjectivePoint
Calculates SECP256k1 endomorphism: self * lambda.
pub fn eq_affine(&self, other: &AffinePoint) -> Choice
pub fn eq_affine(&self, other: &AffinePoint) -> Choice
Check whether self is equal to an affine point.
This is a lot faster than first converting self to an AffinePoint and then doing the
comparison. It is a little bit faster than converting other to a ProjectivePoint first.