Trait PrehashSignature
pub trait PrehashSignature {
type Digest: Digest;
}Expand description
Marker trait for Signature types computable as ๐(๐(๐))
i.e. ones which prehash a message to be signed as ๐(๐)
Where:
๐: signature algorithm๐: hash (a.k.a. digest) function๐: message
This approach is relatively common in signature schemes based on the Fiat-Shamir heuristic.
For signature types that implement this trait, when the derive crate
feature is enabled a custom derive for Signer is available for any
types that impl DigestSigner, and likewise for deriving Verifier for
types which impl DigestVerifier.
Required Associated Types
Implementations on Foreign Types
impl<C> PrehashSignature for Signature<C>
Available on crate feature digest only.
impl<C> PrehashSignature for Signature<C>
Available on crate feature
digest only.type Digest = <C as DigestPrimitive>::Digest
impl<C> PrehashSignature for Signature<C>
Available on crate features digest and hazmat only.
impl<C> PrehashSignature for Signature<C>
Available on crate features
digest and hazmat only.